<?php
session_start();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    <link rel="stylesheet" href="../css/body.css">
    <link rel="stylesheet" href="../css/nodeDetails.css">
</head>
<body>

<?php
require_once "credentials.php";

// Verbindung zur Datenbank herstellen
$dbc = mysqli_connect(DB_HOST, DB_USER, DB_PW, DB_NAME);

if (mysqli_connect_errno()) {
    die('Connection Error (' . mysqli_connect_errno() . '): ' . mysqli_connect_error());
}

mysqli_set_charset($dbc, 'utf8');

if (isset($_GET['node_id'])) {
    $nodeId = intval($_GET['node_id']);

    //Node Details anzeigen
    $query = "
            SELECT 
                Node.name AS node_name,
                PlantVariety.commonName AS plant_variety,
                PlantVariety.botanicalName AS botanical_name,
                CONCAT(Operator.firstname, ' ', Operator.lastname) AS operator_name,
                Node.plantingDate AS planting_date
            FROM Node
            LEFT JOIN PlantVariety ON Node.fk_plantVariety_contains = PlantVariety.pk_plantVariety
            LEFT JOIN Operator ON Node.fk_operator_belongs = Operator.pk_operator
            WHERE Node.pk_node = $nodeId
        ";

    $result = mysqli_query($dbc, $query);

    if ($result && $row = mysqli_fetch_assoc($result)) {
        // Überprüfen, ob der Node online ist
        $queryOnlineStatus = "
            SELECT MAX(recordDateTime) AS last_record_time 
            FROM Measurement 
            WHERE fk_node_isRecorded = $nodeId
        ";

        $resultOnlineStatus = mysqli_query($dbc, $queryOnlineStatus);
        $isOnline = false;

        if ($resultOnlineStatus && $rowStatus = mysqli_fetch_assoc($resultOnlineStatus)) {
            $lastRecordTime = $rowStatus['last_record_time'];
            if ($lastRecordTime && strtotime($lastRecordTime) >= strtotime('-10 minutes')) {
                $isOnline = true;
            }
        }

        $onlineStatus = $isOnline ? "Online" : "Offline";

        echo '<h2>Node Details</h2>';
        echo '<table>';
        echo '<tr><th>Node Name</th><td>' . ($row['node_name'] ?: 'N/A') . '</td></tr>';
        echo '<tr><th>Plant Variety</th><td>' . ($row['plant_variety'] ?: 'N/A') . '</td></tr>';
        echo '<tr><th>Botanical Name</th><td>' . ($row['botanical_name'] ?: 'N/A') . '</td></tr>';
        echo '<tr><th>Operator Name</th><td>' . ($row['operator_name'] ?: 'N/A') . '</td></tr>';
        echo '<tr><th>Planting Date</th><td>' . ($row['planting_date'] ?: 'N/A') . '</td></tr>';
        echo '<tr><th>Status</th><td>' . $onlineStatus . '</td></tr>';
        echo '</table>';
    } else {
        echo '<p>Node details not found.</p>';
    }

    // Die Messwerte anzeigen lassen
    $queryMeasurements = "
            SELECT 
                Measurement.recordDateTime AS timestamp,
                Measurement.soilMoisture AS soil_moisture,
                Measurement.airHumidity AS air_humidity,
                Measurement.airTemperature AS air_temperature,
                Measurement.ambientBrightness AS ambient_brightness,
                Measurement.lampBrightness AS lamp_brightness
            FROM Measurement
            WHERE Measurement.fk_node_isRecorded = $nodeId
            ORDER BY Measurement.recordDateTime DESC
            LIMIT 2
        ";

    $resultMeasurements = mysqli_query($dbc, $queryMeasurements);

    if ($resultMeasurements && mysqli_num_rows($resultMeasurements) > 0) {
        echo '<h2>Measurement Data</h2>';
        echo '<table>';
        echo '<tr><th>Timestamp</th><th>Soil Moisture</th><th>Air Humidity</th><th>Air Temperature</th><th>Ambient Brightness</th><th>Lamp Brightness</th></tr>';
        while ($rowMeasurement = mysqli_fetch_assoc($resultMeasurements)) {
            echo '<tr>';
            echo '<td>' . ($rowMeasurement['timestamp'] ?: 'N/A') . '</td>';
            echo '<td>' . ($rowMeasurement['soil_moisture'] ?: 'N/A'). " %" . '</td>';
            echo '<td>' . ($rowMeasurement['air_humidity'] ?: 'N/A') . " %" . '</td>';
            echo '<td>' . ($rowMeasurement['air_temperature'] ?: 'N/A') . " C" .'</td>';
            echo '<td>' . ($rowMeasurement['ambient_brightness'] ?: 'N/A')  .'</td>';
            echo '<td>' . ($rowMeasurement['lamp_brightness'] ?: '0') . " %" . '</td>';
            echo '</tr>';
        }
        echo '</table>';
    } else {
        echo '<p>No measurement data found for this node.</p>';
    }



    //Licht Helligkeit angeben
    echo '<div style="display: flex; justify-content: space-between;">';

    echo '<div style="flex: 1; margin-right: 20px;">';
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['brightness'])) {
        $brightness = intval($_POST['brightness']); // Helligkeit aus dem Formular

        // SQL-Abfrage für das Einfügen der Aufgabe in die Tabelle Task
        $insertBrightnessTaskQuery = "
        INSERT INTO Task (scheduledDateTime, taskType, setPoint, completionFlag, fk_node_isAssigned) 
        VALUES (NOW(), 'light', $brightness, 0, $nodeId)
    ";

        // Ausführen der Abfrage
        if (mysqli_query($dbc, $insertBrightnessTaskQuery)) {
            echo "<p>Task successfully added to the database: Set lamp brightness to $brightness%!</p>";
        } else {
            echo "<p>Error adding task: " . mysqli_error($dbc) . "</p>";
        }
    }


// Button-Container für die Aktionen
    echo '<div class="button-container">';
    echo "<button type='button' class='action-button' onclick='setBrightness(0)'>Lamp Brightness 0%</button>";
    echo "<button type='button' class='action-button' onclick='setBrightness(100)'>Lamp Brightness 100%</button>";
    echo '</div>';

// Slider für benutzerdefinierte Helligkeit
    echo '<div class="slider-container">';
    echo '<form method="post">';
    echo '<label for="brightness">Set Lamp Brightness:</label>';
    echo '<input type="range" id="brightness" name="brightness" min="0" max="100" value="0" oninput="this.nextElementSibling.value = this.value">';
    echo '<output>0</output>%  ';
    echo '<button type="submit" class="action-button">Set Brightness</button>';
    echo '</form>';
    echo '</div>';
    echo '</div>';





    // Wassermenge pumpen und in der Datenbank speichern
    echo '<div style="flex: 1; margin-left: 20px;">';

    //Standard menge in ml
    $pumpAmount = 100;

    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['pump_amount'])) {
        $pumpAmount = intval($_POST['pump_amount']);

        // SQL-Abfrage für das Einfügen der Aufgabe in die Tabelle Task
        $insertTaskQuery = "
        INSERT INTO Task (scheduledDateTime, taskType, setPoint, completionFlag, fk_node_isAssigned) 
        VALUES (NOW(), 'pump', $pumpAmount, 0, $nodeId)
    ";

        if (mysqli_query($dbc, $insertTaskQuery)) {
            echo "<p>Task successfully added to the database: Pump $pumpAmount ml water!</p>";
        } else {
            echo "<p>Error adding task: " . mysqli_error($dbc) . "</p>";
        }
    }

    echo '<form method="post">';
    echo '<div class="button-container">';
    echo '<label for="pump_amount">Amount of Water (ml):</label>';
    echo '<input type="number" id="pump_amount" name="pump_amount" value="100" pattern="\\d+" required>';
    echo '<button type="submit" class="action-button">Pump</button>';
    echo '</div>';
    echo '</form>';
    echo '</div>';
    echo '</div>';




    // JavaScript-Code für die Buttons
    echo '<script>
    function setBrightness(value) {
        const slider = document.getElementById("brightness");
        const output = slider.nextElementSibling;
        slider.value = value;
        output.value = value;
    }
</script>';



// Button für die Rückkehr zur Node-Liste

    echo '<form method="post">';
    echo '<button type="submit" class="back-button" name="back_button">Back to Node List</button>';
    echo '</form>';


    if (isset($_POST['back_button'])) {
        // Umleitung zur gewünschten Seite
        header("Location: index.php?page=nodes");
        exit();
    }



// Datenbankverbindung schließen
    mysqli_close($dbc);
}
?>

</body>
</html>
