<?php
session_start();
error_reporting(E_ALL);
ini_set('display_errors', 1);

if (!isset($_SESSION['user_name']) || !isset($_SESSION['operator_id'])) {
    header("Location: login.php");
    exit();
}

require_once "credentials.php";

$dbc = mysqli_connect(DB_HOST, DB_USER, DB_PW, DB_NAME);
if (!$dbc) {
    die('<p>Datenbankverbindungsfehler: ' . mysqli_connect_error() . '</p>');
}
mysqli_set_charset($dbc, 'utf8');

$nodeId = isset($_POST['node_id']) ? intval($_POST['node_id']) : null;
if (!$nodeId) {
    die('<p>Error: Node ID fehlt.</p>');
}

// API Endpoint für Steuerungsupdates
if (isset($_POST['action']) && $_POST['action'] === 'update_controls') {
    $taskType = isset($_POST['pump_duration']) && intval($_POST['pump_duration']) > 0 ? 'pump' : 'light';
    $setValue = $taskType === 'pump' ? intval($_POST['pump_duration']) : intval($_POST['target_brightness']);
    $nodeId = $_POST['node_id']; // Übergebe die node_id aus der Anfrage

    // Datum und Uhrzeit hinzufügen
    $dateTime = isset($_POST['date_time']) ? $_POST['date_time'] : date('Y-m-d H:i:s'); // Default auf jetzige Zeit, wenn nicht angegeben

    // SQL-Abfrage zum Einfügen eines neuen Tasks in die Tabelle
    $queryInsertTask = "INSERT INTO Task (taskType, setPoint, fk_node_isAssigned, recordDateTime) VALUES (?, ?, ?, ?)";
    $stmt = mysqli_prepare($dbc, $queryInsertTask);
    if ($stmt === false) {
        die('<p>Fehler bei der SQL-Statement-Vorbereitung: ' . mysqli_error($dbc) . '</p>');
    }

    mysqli_stmt_bind_param($stmt, 'siis', $taskType, $setValue, $nodeId, $dateTime);

    if (mysqli_stmt_execute($stmt)) {
        echo json_encode(['success' => true]);
    } else {
        echo json_encode(['success' => false, 'error' => mysqli_error($dbc)]);
    }
    exit();
}


$startDate = isset($_POST['start_date']) ? $_POST['start_date'] : date('Y-m-d', strtotime('-1 day'));
$endDate = isset($_POST['end_date']) ? $_POST['end_date'] : date('Y-m-d');

$operatorId = $_SESSION['operator_id'];
$queryCheckNode = "SELECT name FROM Node WHERE pk_node = ? AND fk_operator_belongs = ?";
$stmt = mysqli_prepare($dbc, $queryCheckNode);
mysqli_stmt_bind_param($stmt, 'ii', $nodeId, $operatorId);
mysqli_stmt_execute($stmt);
$resultNode = mysqli_stmt_get_result($stmt);

if (mysqli_num_rows($resultNode) === 0) {
    die('<p>Error: Keine Berechtigung für diese Node.</p>');
}

$nodeName = mysqli_fetch_assoc($resultNode)['name'];

$queryMeasurements = "
    SELECT recordDateTime, soilMoisture, airTemperature, airHumidity, ambientBrightness, lampBrightness
    FROM Measurement
    WHERE fk_node_isRecorded = ?
    AND DATE(recordDateTime) BETWEEN ? AND ?
    ORDER BY recordDateTime ASC
";

$stmt = mysqli_prepare($dbc, $queryMeasurements);
mysqli_stmt_bind_param($stmt, 'iss', $nodeId, $startDate, $endDate);
mysqli_stmt_execute($stmt);
$resultMeasurements = mysqli_stmt_get_result($stmt);

$measurements = [];
while ($row = mysqli_fetch_assoc($resultMeasurements)) {
    $measurements[] = [
        'x' => $row['recordDateTime'],
        'soilMoisture' => floatval($row['soilMoisture']),
        'airTemperature' => floatval($row['airTemperature']),
        'airHumidity' => floatval($row['airHumidity']),
        'brightness' => floatval($row['ambientBrightness']),
        'lampBrightness' => floatval($row['lampBrightness'])
    ];
}

mysqli_close($dbc);
?>

<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Node Details - Plantimeter</title>
    <link rel="stylesheet" href="css/userView.css">
    <link rel="stylesheet" href="css/adminNavbar.css">
    <link rel="stylesheet" href="css/logout.css">
    <script src="https://cdn.jsdelivr.net/npm/moment@2.29.4/moment.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/chart.js@4.4.1/dist/chart.umd.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/chartjs-adapter-moment@1.0.1/dist/chartjs-adapter-moment.min.js"></script>
    <style>
        /* Deine CSS-Styles bleiben unverändert */
    </style>
</head>
<body>
<div class="navbar">
    <a href="index.php?page=viewUser">Nodes</a>
    <a href="index.php?page=userResetPw">Account</a>
    <a href="index.php?page=userPlant">Add Plants</a>
    <a href="index.php">Logout</a>
</div>

<h2 class="node-title">Measured values for Node: <?php echo htmlspecialchars($nodeName); ?></h2>

<div class="main-container">
    <div class="left-panel">
        <h3>Select time period</h3>
        <form id="dateForm" class="date-form" method="POST" action="index.php?page=UserNodeDetails">
            <input type="hidden" name="node_id" value="<?php echo $nodeId; ?>">

            <div>
                <label for="start_date">From:</label>
                <input type="date" id="start_date" name="start_date" value="<?php echo $startDate; ?>" required>
            </div>

            <div>
                <label for="end_date">To:</label>
                <input type="date" id="end_date" name="end_date" value="<?php echo $endDate; ?>" required>
            </div>

            <button type="submit">Create Diagram</button>
        </form>

        <div class="chart-container">
            <?php if (!empty($measurements)): ?>
                <canvas id="measurementChart"></canvas>
            <?php else: ?>
                <p>No Measurements found</p>
            <?php endif; ?>
        </div>
    </div>

    <div class="right-panel">
        <h3>Add a Task</h3>
        <div class="control-panel">
            <div class="slider-container">
                <label for="pumpDuration">Pumping Water in Milliliters:</label>
                <input type="range" id="pumpDuration" min="0" max="500" value="0" step="1">
                <span class="value-display" id="pumpDurationValue">0ml</span><br>
                <button onclick="activatePump()">Add Pump</button>
            </div>

            <div class="slider-container">
                <label for="targetBrightness">Set brightness:</label>
                <input type="range" id="targetBrightness" min="0" max="100" value="0" step="1">
                <span class="value-display" id="targetBrightnessValue">0%</span><br>
                <button onclick="updateBrightness()">Add Brightness</button>
            </div>

            <div class="slider-container">
                <label for="taskDateTime">Datum und Uhrzeit:</label>
                <input type="datetime-local" id="taskDateTime" name="taskDateTime" required>
            </div>
        </div>
    </div>
</div>
<style>
    body {
        font-family: Arial, sans-serif;
        background-color: #e0f7fa;
        margin: 0;
        padding: 0;
    }

    h2.node-title {
        text-align: center;
        font-size: 24px;
        color: #00796b;
        margin-top: 20px;
    }

    .main-container {
        display: flex;
        justify-content: space-between;
        margin: 30px;
    }

    .left-panel, .right-panel {
        width: 70%;
        background-color: white;
        padding: 100px;
        border-radius: 8px;
        box-shadow: 0px 4px 10px rgba(0, 0, 0, 0.1);
        margin-right: 50px;
    }

    .left-panel h3, .right-panel h3 {
        font-size: 20px;
        color: #00796b;
        margin-bottom: 10px;
    }

    .date-form {
        display: flex;
        flex-direction: column;
        margin-bottom: 20px;
    }

    .date-form div {
        margin-bottom: 10px;
    }

    .date-form input[type="date"] {
        padding: 10px;
        border-radius: 5px;
        border: 1px solid #00796b;
        font-size: 16px;
        width: 100%;
    }

    button {
        background-color: #00796b;
        color: white;
        border: none;
        padding: 10px 15px;
        font-size: 16px;
        border-radius: 5px;
        cursor: pointer;
        transition: background-color 0.3s;
    }

    button:hover {
        background-color: #004d40;
    }

    .chart-container {
        margin-top: 20px;
        max-width: 100%;
        height: 350px;
    }

    .slider-container {
        margin-bottom: 20px;
    }

    .slider-container input[type="range"] {
        width: 100%;
        padding: 10px 0;
        margin-bottom: 10px;
        border-radius: 10px;
        background: #00796b;
        transition: background 0.3s;
    }

    .slider-container input[type="range"]:focus {
        background: #004d40;
    }

    .value-display {
        display: block;
        font-size: 18px;
        margin-top: 10px;
        text-align: center;
        color: #00796b;
    }

    .slider-container button {
        background-color: #00796b;
        width: 100%;
        padding: 12px;
        border: none;
        border-radius: 8px;
        color: white;
        cursor: pointer;
        transition: background-color 0.3s;
    }

    .slider-container button:hover {
        background-color: #004d40;
    }

    h3 {
        text-align: center;
        font-size: 22px;
        color: #00796b;
    }
</style>

<script>
    const measurements = <?php echo json_encode($measurements); ?>;

    if (measurements.length > 0) {
        const ctx = document.getElementById('measurementChart').getContext('2d');
        new Chart(ctx, {
            type: 'line',
            data: {
                datasets: [
                    {
                        label: 'Bodenfeuchte',
                        data: measurements.map(m => ({ x: new Date(m.x), y: m.soilMoisture })),
                        borderColor: 'blue',
                        fill: false,
                        borderWidth: 2
                    },
                    {
                        label: 'Lufttemperatur',
                        data: measurements.map(m => ({ x: new Date(m.x), y: m.airTemperature })),
                        borderColor: 'red',
                        fill: false,
                        borderWidth: 2
                    },
                    {
                        label: 'Luftfeuchtigkeit',
                        data: measurements.map(m => ({ x: new Date(m.x), y: m.airHumidity })),
                        borderColor: 'green',
                        fill: false,
                        borderWidth: 2
                    },
                    {
                        label: 'Helligkeit',
                        data: measurements.map(m => ({ x: new Date(m.x), y: m.brightness })),
                        borderColor: 'yellow',
                        fill: false,
                        borderWidth: 2
                    },
                    {
                        label: 'Lampenhelligkeit',
                        data: measurements.map(m => ({ x: new Date(m.x), y: m.lampBrightness })),
                        borderColor: 'orange',
                        fill: false,
                        borderWidth: 2
                    }
                ]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                aspectRatio: 2,
                scales: {
                    x: {
                        type: 'time',
                        time: { unit: 'hour' },
                        title: {
                            display: true,
                            text: 'Zeit',
                            font: {
                                size: 14
                            }
                        },
                        ticks: {
                            font: {
                                size: 12
                            }
                        }
                    },
                    y: {
                        beginAtZero: true,
                        title: {
                            display: true,
                            text: 'Messwerte',
                            font: {
                                size: 14
                            }
                        },
                        ticks: {
                            font: {
                                size: 12
                            }
                        }
                    }
                },
                plugins: {
                    legend: {
                        position: 'top',
                        labels: {
                            font: {
                                size: 12
                            },
                            padding: 20
                        }
                    },
                    title: {
                        display: true,
                        text: 'Messwerte Verlauf',
                        font: {
                            size: 16,
                            weight: 'bold'
                        },
                        padding: 20
                    }
                }
            }
        });
    }

    document.getElementById('pumpDuration').addEventListener('input', function() {
        document.getElementById('pumpDurationValue').textContent = this.value + 'ml';
    });

    document.getElementById('targetBrightness').addEventListener('input', function() {
        document.getElementById('targetBrightnessValue').textContent = this.value + '%';
    });

    function activatePump() {
        const pumpDuration = document.getElementById('pumpDuration').value;
        const taskDateTime = document.getElementById('taskDateTime').value; // Datum und Uhrzeit abfragen

        fetch('index.php?page=UserNodeDetails', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify({
                action: 'update_controls',
                pump_duration: pumpDuration,
                node_id: <?php echo $nodeId; ?>,
                date_time: taskDateTime // Datum und Uhrzeit übergeben
            })
        }).then(response => response.json()).then(data => {
            if (data.success) {
                alert('Pumpe aktiviert!');
            } else {
                alert('Fehler bei der Pumpe: ' + data.error);
            }
        });
    }

    function updateBrightness() {
        const brightness = document.getElementById('targetBrightness').value;
        const taskDateTime = document.getElementById('taskDateTime').value; // Datum und Uhrzeit abfragen

        fetch('index.php?page=UserNodeDetails', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify({
                action: 'update_controls',
                target_brightness: brightness,
                node_id: <?php echo $nodeId; ?>,
                date_time: taskDateTime // Datum und Uhrzeit übergeben
            })
        }).then(response => response.json()).then(data => {
            if (data.success) {
                alert('Helligkeit angepasst!');
            } else {
                alert('Fehler bei der Helligkeit: ' + data.error);
            }
        });
    }
</script>
</body>
</html>
