<?php
session_start();
error_reporting(E_ALL);
ini_set('display_errors', 1);

require_once "credentials.php";

$dbc = mysqli_connect(DB_HOST, DB_USER, DB_PW, DB_NAME);
if (!$dbc) {
    die('Database connection failed: ' . mysqli_connect_error());
}
mysqli_set_charset($dbc, 'utf8');

// Handle plant variety submission
if (isset($_POST['add_plant'])) {
    $stmt = mysqli_prepare($dbc, "INSERT INTO PlantVariety (commonName, botanicalName, ambientBrightnessThreshold, soilMoistureThreshold, airTemperatureOptimal, airHumidityOptimal) VALUES (?, ?, ?, ?, ?, ?)");
    mysqli_stmt_bind_param($stmt, 'ssdddd',
        $_POST['commonName'],
        $_POST['botanicalName'],
    $_POST['ambientBrightnessThreshold'],
    $_POST['soilMoistureThreshold'],
    $_POST['airTemperatureOptimal'],
    $_POST['airHumidityOptimal']
    );
    mysqli_stmt_execute($stmt);
}

// Handle node assignment
if (isset($_POST['assign_plant'])) {
    $stmt = mysqli_prepare($dbc, "UPDATE Node SET fk_plantVariety_contains = ?, plantingDate = CURRENT_TIMESTAMP WHERE pk_node = ?");
    mysqli_stmt_bind_param($stmt, 'ii',
        $_POST['plant_variety_id'],
        $_POST['node_id']
    );
    mysqli_stmt_execute($stmt);
}

// Get all plant varieties
$plants = mysqli_query($dbc, "SELECT * FROM PlantVariety");

// Get all nodes
$nodes = mysqli_query($dbc, "SELECT * FROM Node");
?>

    <!DOCTYPE html>
    <html lang="en">
    <head>
        <meta charset="UTF-8">
        <title>Plant Management</title>

        <link rel="stylesheet" href="css/userView.css">
        <link rel="stylesheet" href="css/adminNavbar.css">
        <link rel="stylesheet" href="css/logout.css">
        <link rel="stylesheet" href="css/addPlantArt.css">
    </head>
    <body>

    <div class="navbar">
        <a href="index.php?page=viewUser">Nodes</a>
        <a href="index.php?page=userResetPw">Account</a>
        <a href="index.php?page=userPlant">Add Plants</a>
        <a href="index.php">Logout</a>
    </div>

    <h2>Add New Plant Variety</h2>
    <form method="post">
        <div>
            <label>Common Name: <input type="text" name="commonName" required></label>
            <label>Botanical Name: <input type="text" name="botanicalName" required></label>
            <label>Light (lux): <input type="number" name="ambientBrightnessThreshold" required></label>
            <label>Soil Moisture (%): <input type="number" name="soilMoistureThreshold" required> </label>
            <label>Air Temperature (°C): <input type="number" name="airTemperatureOptimal" required></label>
            <label>Air Humidity (%): <input type="number" name="airHumidityOptimal" required></label>
        </div>
        <button type="submit" name="add_plant">Add Plant Variety</button>
    </form>

    <h2>Assign Plant to Node</h2>
    <form method="post">
        <select name="node_id" required>
            <option value="">Select Node</option>
              <?php while ($node = mysqli_fetch_assoc($nodes)): ?>
                <option value="<?php echo $node['pk_node']; ?>">
                    <?php echo htmlspecialchars($node['name']); ?>
                </option>
            <?php endwhile; ?>
        </select>

        <select name="plant_variety_id" required>
            <option value="">Select Plant Variety</option>
            <?php while ($plant = mysqli_fetch_assoc($plants)): ?>
                <option value="<?php echo $plant['pk_plantVariety']; ?>">
                    <?php echo htmlspecialchars($plant['commonName']); ?>
                </option>
            <?php endwhile; ?>
        </select>

        <button type="submit" name="assign_plant">Assign Plant</button>
    </form>
    </body>
    </html>

<?php mysqli_close($dbc); ?>