<?php
session_start();
require_once "credentials.php";
require_once "functions.php";

// Überprüfe, ob der Benutzer eingeloggt ist
if (!isset($_SESSION['user_name'])) {
    die('<p>Error: User is not logged in.</p>');
}

if (isset($_POST['submit_new_password'])) {

    $dbc = mysqli_connect(DB_HOST, DB_USER, DB_PW, DB_NAME);
    if (!$dbc) {
        die('<p>Datenbankverbindungsfehler: ' . mysqli_connect_error() . '</p>');
    }

    // Eingabewerte sicher einlesen
    $emailAddress = $_SESSION['user_name']; // Angenommen, die E-Mail-Adresse des Benutzers ist in der Session gespeichert
    $newPassword = $_POST['new_password'];

    if (empty($newPassword)) {
        die('<p>Error: New password is empty.</p>');
    }

    // Passwort hashen
    $hashedPassword = password_hash($newPassword, PASSWORD_DEFAULT);

    // Debugging-Ausgabe
    echo "E-Mail: $emailAddress, Gehashtes Passwort: $hashedPassword";

    // Passwort in der Datenbank zurücksetzen
    $passwordResetQuery = "UPDATE Operator SET passwordHash = ? WHERE emailAddress = ?";
    $stmt = mysqli_prepare($dbc, $passwordResetQuery);

    if ($stmt) {
        mysqli_stmt_bind_param($stmt, 'ss', $hashedPassword, $emailAddress); // Wir verwenden 'emailAddress' statt 'username'
        if (mysqli_stmt_execute($stmt)) {
            // Erfolgreiche Passwortänderung
            echo "<p class='success'>Passwort erfolgreich geändert.</p>";

            // Session zerstören, um den Benutzer abzumelden
            session_destroy();  // Zerstört alle Session-Daten
            header("Location: index.php");
            exit();  // Beendet das Skript
        } else {
            echo "<p class='error'>Fehler beim Zurücksetzen des Passworts: " . mysqli_error($dbc) . "</p>";
        }
        mysqli_stmt_close($stmt);
    } else {
        echo "<p class='error'>Fehler beim Vorbereiten der SQL-Abfrage: " . mysqli_error($dbc) . "</p>";
    }

    // Verbindung schließen
    mysqli_close($dbc);
}

logoff($_POST['DATA_logout']);
?>



<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Passwort ändern</title>
    <link rel="stylesheet" href="css/userView.css">
    <link rel="stylesheet" href="css/logout.css">
    <link rel="stylesheet" href="css/adminNavbar.css">
</head>
<body>

<div class="navbar">
    <a href="index.php?page=viewUser">Nodes</a>
    <a href="index.php?page=userResetPw">Account</a>
    <a href="index.php?page=userPlant">Add Plants</a>
    <a href="index.php">Logout</a>
</div>

<img src="images/logo/800/logo_tp.png" alt="Plantimeter Logo">
<h1>Passwort ändern</h1>

<form method="post">
    <label for="new_password">Neues Passwort:</label>
    <input type="password" id="new_password" name="new_password" required>

    <button type="submit" name="submit_new_password">Passwort ändern</button>
</form>

</body>
</html>
