<?php
session_start();

// Überprüfen, ob der Benutzer eingeloggt ist
if (!isset($_SESSION['user_name']) || !isset($_SESSION['operator_id'])) {
    header("Location: login.php"); // Falls nicht eingeloggt, zur Login-Seite weiterleiten
    exit();
}

require_once "credentials.php";
require_once "functions.php";

// Verbindung zur Datenbank herstellen
$dbc = mysqli_connect(DB_HOST, DB_USER, DB_PW, DB_NAME);
if (!$dbc) {
    die('Datenbankverbindungsfehler: ' . mysqli_connect_error());
}
mysqli_set_charset($dbc, 'utf8');

$operatorId = $_SESSION['operator_id'];

// SQL-Abfrage: Nur Nodes des aktuellen Benutzers abrufen
$query = "SELECT pk_node, name AS node_name FROM Node WHERE fk_operator_belongs = ? ORDER BY pk_node";
$stmt = mysqli_prepare($dbc, $query);
mysqli_stmt_bind_param($stmt, 'i', $operatorId);
mysqli_stmt_execute($stmt);
$result = mysqli_stmt_get_result($stmt);
?>

<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Welcome to Plantimeter</title>
    <link rel="stylesheet" href="css/userView.css">
    <link rel="stylesheet" href="css/adminNavbar.css">
    <link rel="stylesheet" href="css/logout.css">
</head>
<body>
<div class="navbar">
    <a href="index.php?page=viewUser">Nodes</a>
    <a href="index.php?page=userResetPw">Account</a>
    <a href="index.php?page=userPlant">Add Plants</a>
    <a href="index.php">Logout</a>
</div>

<img src="images/logo/800/logo_tp.png" alt="Plantimeter Logo">
<h1>Welcome to Plantimeter</h1>
<div class='account'>You are logged in as <strong><?php echo htmlspecialchars($_SESSION['user_name']); ?></strong></div>

<?php if ($result && mysqli_num_rows($result) > 0): ?>
    <table>
        <tr>
            <th>Node Name</th>
            <th>Details</th>
        </tr>
        <?php while ($row = mysqli_fetch_assoc($result)): ?>
            <tr>
                <td><?php echo htmlspecialchars($row['node_name'] ?: 'N/A'); ?></td>
                <td>
                    <form action="index.php?page=UserNodeDetails" method="post" style="display:inline;">
                        <input type="hidden" name="node_id" value="<?php echo (int)$row['pk_node']; ?>">
                        <button type="submit">View Details</button>
                    </form>
                </td>
            </tr>
        <?php endwhile; ?>
    </table>
<?php else: ?>
    <p>No Nodes Found.</p>
<?php endif; ?>

<?php mysqli_close($dbc); ?>
</body>
</html>
